==> ravegen_dev-0.1.9-py2-none-any.whl: ravegen/RaveEngine/projectManager.py <==
import os
import sys
import Utils.sad as sad
import Utils.commandManager as commandManager
import configManager as configManager

def createInitProject(fillConfig=True, createBasicModules=False, TOKEN = None):
    commandManager.runMkdirCommand(sad._CONFIG_DIR_NAME_)
    commandManager.runMkdirCommand(sad._MODULES_DIR_)
    commandManager.runMkdirCommand(sad._LOG_DIR_NAME_)
    reqFile = open(sad._CONFIG_REQ_FILE_PAHT_, 'w')
    reqFile.write("python-telegram-bot\n")
    reqFile.close()
    if(fillConfig == True):
        configManager.createInitConfig()
    if(createBasicModules == True):
        _createBasicModules()
    if(TOKEN != None):
        config = configManager.getConfig()
        configManager.set(config, sad._CONFIG_RAVEGEN_SECTION_, sad._CONFIG_TOKEN_OPTION_, TOKEN)


def _createBasicModules():
    moduleFile = open(sad._MODULES_DIR_ + sad._DF_ + "start.py", 'w')
    moduleFile.write("from ravegen import *\n\n")
    moduleFile.write("@RaveGen\n")
    moduleFile.write("@Command\n")
    moduleFile.write("def start(message):\n")
    moduleFile.write("\treturn 'Hello, tell me something'\n")
    moduleFile.close()
    moduleFile = open(sad._MODULES_DIR_ + sad._DF_ + "echo.py", 'w')
    moduleFile.write("from ravegen import *\n\n")
    moduleFile.write("@RaveGen\n")
    moduleFile.write("@Text\n")
    moduleFile.write("def echo(message):\n")
    moduleFile.write("\treturn message\n")
    moduleFile.close()
    moduleFile = open(sad._MODULES_DIR_ + sad._DF_ + "caps.py", 'w')
    moduleFile.write("from ravegen import *\n\n")
    moduleFile.write("@RaveGen\n")
    moduleFile.write("@Command\n")
    moduleFile.write("def caps(message):\n")
    moduleFile.write("\tif message == '':\n")
    moduleFile.write("\t\treturn 'Falta el argumento'\n")
    moduleFile.write("\treturn message.upper()\n")
    moduleFile.close()
    moduleFile = open(sad._MODULES_DIR_ + sad._DF_ + "error.py", 'w')
    moduleFile.write("from ravegen import *\n\n")
    moduleFile.write("@RaveGen\n")
    moduleFile.write("@Error\n")
    moduleFile.write("def error(message):\n")
    moduleFile.write("\treturn 'ERROR: ' + message\n")
    moduleFile.close()

==> ravegen_dev-0.1.20-py2-none-any.whl: ravegen/RaveEngine/projectManager.py <==
import os
import sys
import Utils.sad as sad
import Utils.commandManager as commandManager
import configManager as configManager

def createInitProject(fillConfig=True, createBasicModules=False, TOKEN = None):
    commandManager.runMkdirCommand(sad._CONFIG_DIR_NAME_)
    commandManager.runMkdirCommand(sad._MODULES_DIR_)
    commandManager.runMkdirCommand(sad._LOG_DIR_NAME_)
    reqFile = open(sad._CONFIG_REQ_FILE_PAHT_, 'w')
    reqFile.write("ravegen-dev\n")
    reqFile.close()
    runtimeFile = open(sad._CONFIG_RUNTIME_FILE_PATH_, 'w')
    runtimeFile.write("python-2.7.15\n")
    runtimeFile.close()
    if(fillConfig == True):
        configManager.createInitConfig()
    if(createBasicModules == True):
        _createBasicModules()
    if(TOKEN != None):
        config = configManager.getConfig()
        configManager.set(config, sad._CONFIG_RAVEGEN_SECTION_, sad._CONFIG_TOKEN_OPTION_, TOKEN)


def _createBasicModules():
    moduleFile = open(sad._MODULES_DIR_ + sad._DF_ + "start.py", 'w')
    moduleFile.write("from ravegen import *\n\n")
    moduleFile.write("@RaveGen\n")
    moduleFile.write("@Command\n")
    moduleFile.write("def start(message):\n")
    moduleFile.write("\treturn 'Hello, tell me something'\n")
    moduleFile.close()
    moduleFile = open(sad._MODULES_DIR_ + sad._DF_ + "echo.py", 'w')
    moduleFile.write("from ravegen import *\n\n")
    moduleFile.write("@RaveGen\n")
    moduleFile.write("@Text\n")
    moduleFile.write("def echo(message):\n")
    moduleFile.write("\treturn message\n")
    moduleFile.close()
    moduleFile = open(sad._MODULES_DIR_ + sad._DF_ + "caps.py", 'w')
    moduleFile.write("from ravegen import *\n\n")
    moduleFile.write("@RaveGen\n")
    moduleFile.write("@Command\n")
    moduleFile.write("def caps(message):\n")
    moduleFile.write("\tif message == '':\n")
    moduleFile.write("\t\treturn 'The argument is missing'\n")
    moduleFile.write("\treturn message.upper()\n")
    moduleFile.close()
    moduleFile = open(sad._MODULES_DIR_ + sad._DF_ + "error.py", 'w')
    moduleFile.write("from ravegen import *\n\n")
    moduleFile.write("@RaveGen\n")
    moduleFile.write("@Error\n")
    moduleFile.write("def error(message):\n")
    moduleFile.write("\treturn 'ERROR: ' + message\n")
    moduleFile.close()
